@@ -33,21 +33,23 @@
 #include <gstreamermm/pluginfeature.h>
 #include <gstreamermm/preset.h>
 #include <gstreamermm/query.h>
+#include <gstreamermm/registry.h>
 #include <gstreamermm/segment.h>
 #include <gstreamermm/structure.h>
 #include <gstreamermm/systemclock.h>
 #include <gstreamermm/taglist.h>
 #include <gstreamermm/tagsetter.h>
 #include <gstreamermm/task.h>
-//TODO: #include <gstreamermm/typefind.h>
-//TODO: #include <gstreamermm/typefindfactory.h>
+#include <gstreamermm/taskpool.h>
+#include <gstreamermm/typefind.h>
+#include <gstreamermm/typefindfactory.h>
 #include <gstreamermm/urihandler.h>
 #include <gstreamermm/value.h>
 #include <gstreamermm/xml.h>
 
 // Core library base includes
-#include <gstreamermm/basesrc.h>
 #include <gstreamermm/basesink.h>
+#include <gstreamermm/basesrc.h>
 #include <gstreamermm/basetransform.h>
 #include <gstreamermm/pushsrc.h>
 
@@ -60,6 +62,7 @@
 #include <gstreamermm/baseaudiosrc.h>
 #include <gstreamermm/cddabasesrc.h>
 #include <gstreamermm/ringbuffer.h>
+#include <gstreamermm/videosink.h>
 
 // Base inteface includes
 #include <gstreamermm/colorbalance.h>
@@ -67,6 +70,7 @@
 #include <gstreamermm/mixer.h>
 #include <gstreamermm/mixeroptions.h>
 #include <gstreamermm/mixertrack.h>
+#include <gstreamermm/navigation.h>
 #include <gstreamermm/propertyprobe.h>
 #include <gstreamermm/tuner.h>
 #include <gstreamermm/tunerchannel.h>
@@ -99,7 +103,7 @@
 #include <gstreamermm/cdparanoiasrc.h>
 #include <gstreamermm/clockoverlay.h>
 #include <gstreamermm/decodebin.h>
-//TODO: #include <gstreamermm/decodebin2.h>
+#include <gstreamermm/decodebin2.h>
 #include <gstreamermm/ffmpegcolorspace.h>
 #include <gstreamermm/gdpdepay.h>
 #include <gstreamermm/gdppay.h>
@@ -109,22 +113,22 @@
 #include <gstreamermm/giostreamsrc.h>
 //TODO (Add plug-in first): #include <gstreamermm/gnomevfssink.h>
 //TODO (Add plug-in first): #include <gstreamermm/gnomevfssrc.h>
-//TODO (Add plug-in first): #include <gstreamermm/multifdsink.h>
+#include <gstreamermm/multifdsink.h>
 #include <gstreamermm/oggdemux.h>
 #include <gstreamermm/oggmux.h>
-//TODO (Add plug-in first): #include <gstreamermm/playbin.h>
+#include <gstreamermm/playbin.h>
 #include <gstreamermm/playbin2.h>
 #include <gstreamermm/tcpclientsrc.h>
 #include <gstreamermm/tcpclientsink.h>
 #include <gstreamermm/tcpserversrc.h>
-//TODO (Add plug-in first): #include <gstreamermm/tcpserversink.h>
+#include <gstreamermm/tcpserversink.h>
 #include <gstreamermm/textoverlay.h>
 #include <gstreamermm/textrender.h>
 #include <gstreamermm/theoradec.h>
 #include <gstreamermm/theoraenc.h>
-//TODO (Add plug-in first): #include <gstreamermm/theoraparse.h>
+#include <gstreamermm/theoraparse.h>
 #include <gstreamermm/timeoverlay.h>
-//TODO (Add plug-in first): #include <gstreamermm/uridecodebin.h>
+#include <gstreamermm/uridecodebin.h>
 #include <gstreamermm/videorate.h>
 #include <gstreamermm/videoscale.h>
 #include <gstreamermm/videotestsrc.h>
